@@ -9,8 +9,8 @@
 #
 package MooseX::AttributeShortcuts;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.032-10-g0ac2e74
-$MooseX::AttributeShortcuts::VERSION = '0.033';
+# git description: 0.033-3-g90bb675
+$MooseX::AttributeShortcuts::VERSION = '0.034';
 
 # ABSTRACT: Shorthand for common attribute options
 
@@ -119,7 +119,7 @@ MooseX::AttributeShortcuts - Shorthand for common attribute options
 
 =head1 VERSION
 
-This document describes version 0.033 of MooseX::AttributeShortcuts - released July 24, 2017 as part of MooseX-AttributeShortcuts.
+This document describes version 0.034 of MooseX::AttributeShortcuts - released July 25, 2017 as part of MooseX-AttributeShortcuts.
 
 =head1 SYNOPSIS
 
@@ -151,9 +151,6 @@ This document describes version 0.033 of MooseX::AttributeShortcuts - released J
     extends 'Some::OtherClass';
     has '+bar' => (traits => [Shortcuts], builder => 1, ...);
 
-    # or...
-    package Some::Other::Class;
-
 =head1 DESCRIPTION
 
 Ever find yourself repeatedly specifying writers and builders, because there's
@@ -492,8 +489,8 @@ so that it can be worked around, fixed, or documented, as appropriate.
 
 =head2 MooseX::SemiAffordanceAccessor
 
-L<MooseX::SemiAffordanceAccessor> changes how the C<is => 'rw'> and
-C<accessor => ...> attribute options work.  If our trait detects that an
+L<MooseX::SemiAffordanceAccessor> changes how the C<< is => 'rw' >> and
+C<< accessor => ... >> attribute options work.  If our trait detects that an
 attribute has had the
 L<MooseX::SemiAffordanceAccessor attribute trait|MooseX::SemiAffordanceAccessor::Role::Attribute>
 applied, then we change our behaviour to conform to its expectations:
@@ -502,16 +499,21 @@ applied, then we change our behaviour to conform to its expectations:
 
 =item *
 
-is => 'rwp'
+C<< is => 'rwp' >>
 
-This is now effectively equivalent to:
+This:
 
-    is => 'ro',
-    writer => '_set_...',
+    has  foo => (is => 'rwp');
+    has _bar => (is => 'rwp');
+
+...is now effectively equivalent to:
+
+    has foo  => (is => 'ro', writer => '_set_foo');
+    has _bar => (is => 'ro', writer => '_set_bar')
 
 =item *
 
-C<writer_prefix> is ignored
+C<-writer_prefix> is ignored
 
 ...as MooseX::SemiAffordanceAccessor has its own specific ideas as to how
 writers should look.
